<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Block_Unibox extends Mage_Core_Block_Text
{

    public function getUniboxData($key, $defaultValue = '')
    {

        $value = Mage::getStoreConfig('semknoxps/unibox/'.$key);

        if(!$value)
        {
            if(is_integer($defaultValue) || $defaultValue == 'undefined')  return $defaultValue;

            if(is_bool($defaultValue))  return ($defaultValue) ? 'true' : 'false';

            return '"'.$defaultValue.'"';

        } else {

            if(is_integer($defaultValue) || $value == 'undefined')  return $value;

            if(is_bool($defaultValue))  return ($value) ? 'true' : 'false';

            return '"'.$value.'"';

        }

    }

    protected function _toHtml()
    {
        /* @var Semknox_ProductSearch_Helper_Data $helper */
        $helper = Mage::helper('semknoxps');

        if(!$helper->semknoxpsUniboxIsActive()) return '';

        $output = array();
        $output[] = " var uniboxSettings = { ";

        $values = array();

        $values[] = " suggestOrder: ['Produkte','Kategorien','Suchvorschläge','Marken']";

        // required:
        $values[] = " suggestUrl: ". $this->getUniboxSuggestUrl(); // the URL that provides the data for the suggest

        // optional:
        $values[] = " instantVisualFeedback: ". $this->getUniboxData('instantVisualFeedback', 'all'); // where the instant visual feedback should be shown, 'top', 'bottom', 'all', or 'none', default: 'all'

        $values[] = " ivfImagePath: ". $this->getUniboxData('ivfImagePath','https://login.semknox.com/images/ivf/');// the path to prepend to the instant visual feedback images

        $values[] = " ivfImageOffset: ". $this->getUniboxData('ivfImageOffset', -80);// the vertical offset of the ivf images

        $values[] = " missingErrorImage: ". $this->getUniboxData('missingErrorImage', 'undefined' );// a default image in case a suggested image was not found

        $values[] = " throttleTime: ". $this->getUniboxData('throttleTime', 300); // the number of milliseconds before the suggest is triggered after finished input, default: 300ms

        //$values[] = " extraHtml: ". $this->getUniboxData('extraHtml', 'undefined'); // extra HTML code that is shown in each search suggest

        $values[] = " placeholder: ". $this->getUniboxData('placeholder', 'undefined'); // the placeholder to be put in the search field

        $values[] = " highlight: ". $this->getUniboxData('highlight', true); // whether matched words should be highlighted, default: true

        $values[] = " queryVisualizationHeadline: ". $this->getUniboxData('queryVisualizationHeadline'); // A headline for the image visualization, default: empty

        $values[] = " animationSpeed: ". $this->getUniboxData('animationSpeed', 300); // speed of the animations, default: 300ms

        $values[] = " enterCallback: function(searchTerm) { jQuery(this).closest('form').submit(); }"; // callback on what should happen when enter is pressed while the focus is in the search field

        $values[] = ' enterCallbackResult: function(productName, productLink) {
            if((typeof productLink === "undefined" || ! productLink) && productName) {
                var $q = jQuery("input[name=q]:visible");
                $q.val(productName)
                     .closest("form")
                     .submit();
            }
            else if(productLink) {
                window.location.href = productLink; 
            }
        }'; // callback on what should happen when enter is pressed while the focus is on one of the suggests, default: undefined, meaning the link will be followed

        $values[] = " minChars: ". $this->getUniboxData('minChars', 3); // minimum number of characters before the suggests shows, default: 3

        $values[] = " maxWidth: ". $this->getUniboxData('maxWidth', 400); // the maximum width of the suggest box, default: as wide as the input box

        $output[] = implode(',', $values);

        $output[] = " }; ";

        // load unibox script (if it's present)
        $output[] = <<<SCRIPT
if(typeof jQuery.fn.unibox !== "undefined") {
    jqElems = jQuery("input[name=q]:visible");

    if(jqElems.length)  {
        jqElems.each(function() {
            var \$el = jQuery(this); 
            // init unibox
            \$el.unibox(uniboxSettings);
        });
        
    }
}
SCRIPT;

        // remove magento auto suggest container
        $output[] = "jQuery('#search_autocomplete').replaceWith('');";

        return '<script type="text/javascript">'.implode($output).'</script>';
    }


    public function getUniboxSuggestUrl()
    {

        /**
         * @var Semknox_ProductSearch_Model_AuthenticationManager $authManager
         */
        $productManager = Mage::getModel('semknoxps/productManager');

        $limit = '';

        $limit .= '&limit='.$this->getUniboxData('limit', 10);
        $limit .= '&limitBrand='.$this->getUniboxData('limitBrand', -1);
        $limit .= '&limitSearch='.$this->getUniboxData('limitSearch', -1);
        $limit .= '&limitCategory='.$this->getUniboxData('limitCategory', -1);
        $limit .= '&limitProduct='.$this->getUniboxData('limitProduct', -1);

        $url = $productManager->getSuggestUrl();
        $helper = Mage::helper('semknoxps');
        $url = $helper->semknoxRequestUrlShortener($url);

        return '"'.$url.$limit.'&query="';

    }
}
