<?php

/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Model_Catalog_Product_Observer
{

    protected $_helper;

    protected $_storesCredentials = array();

    public function __construct()
    {
        /** @var Semknox_ProductSearch_Helper_Data $helper */
        $this->_helper = Mage::helper('semknoxps');

        //get all stores with api credentials
        $this->_storesCredentials = $this->_helper->getAllStoresCredentials();
    }


    public function updateProduct($observer)
    {
        foreach($this->_storesCredentials as $storeId => $store)
        {
            $this->_updateProduct($observer, $storeId);
        }
    }

    /**
     * Catches any Product-Create/Edit/Move/... Event all over the System, gets the
     * affected Products and calls the ProductManager.
     *
     * @param Varien_Event_Observer $observer
     */
    protected function _updateProduct($observer, $storeId)
    {
        /**
         * @var Semknox_ProductSearch_Model_ProductManager $productManager
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $event = $observer->getEvent();
        $productManager = Mage::getModel('semknoxps/productManager', $storeId);
        $helper = Mage::helper('semknoxps');
        $productHelper = Mage::helper('catalog/product');
        $productsArray = array();
        $productIdsNoticedToDelete = array(); // products the are edited to not visible in search

        $log = false;

        // if Product upstream is disabled, dont do anything
        if($helper->semknoxDisableProductUpstream())  return;


        $productIds = false;

        // edit one product
        if($product = $event->getProduct())
        {
            $productIds = array($product->getId());
        } else {
            $productIds = $event->getProductIds();
        }

        // edit products
        if(is_array($productIds))
        {
            $log = implode(',',$productIds);

            $products = Mage::getModel('catalog/product')
                              ->getCollection()
                              ->addAttributeToSelect('*')
                              //->addAttributeToFilter(
                              //  'visibility', array('in'=> Mage::getSingleton('catalog/product_visibility')->getVisibleInSearchIds())
                              //)
                              // -> pass all products to productManager (configurable's simple products will be passed to semknox even if they are "einzeln nciht sichtbar")
                              ->addAttributeToFilter(
                                'entity_id', array('in' => $productIds)
                              )->addAttributeToFilter(
                                'status', array('in'=> Mage::getSingleton('catalog/product_status')->getVisibleStatusIds())
                              );

            $productIdsNoticedToDelete = $productIds;
            foreach($products as $p)
            {
                $productIdsNoticedToDelete = array_diff($productIdsNoticedToDelete, array($p->getId()));
                $productsArray[] = $p;
            }

        }


        // edit inventory
        elseif($item = $event->getItem())
        {
            // check, if inventory was really changed
            if ( (int) $item->getData('qty') != (int) $item->getOrigData('qty')) {

                $productId = $item->getProductId();

                $log = $productId;
                $productsArray[] = Mage::getModel('catalog/product')
                                        ->setStoreId($storeId)
                                        ->load($productId);
            }
        }

        // unknown action
        else {
            $helper->log('unknown Data -> nothing done', 6 );
        }


        if($log)
        {
            $status = ($productManager->updateProducts($productsArray, false)) ? 'success' : 'failed';

            $logLevel = ($status == 'success') ? 6 : 3;

            $status .= ' - '.$productManager->getStatusMessage();

            $log = '['.$event->getName().'] update array('.$log.'): '.$status;
            $helper->log($log, $logLevel, false, $storeId);


            foreach($productIdsNoticedToDelete as $id) {
                $productManager->deleteProductById($id);
            }
        }

    }



    public function deleteProduct($observer)
    {
        foreach($this->_storesCredentials as $storeId => $store)
        {
            $this->_deleteProduct($observer, $storeId);
        }
    }

    protected function _deleteProduct($observer, $storeId) {
        /**
         * @var Semknox_ProductSearch_Model_ProductManager $productManager
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $event = $observer->getEvent();
        $productManager = Mage::getModel('semknoxps/productManager');
        $productsArray = array();
        $helper = Mage::helper('semknoxps');
        $products = '';


        // if Product upstream is disabled, dont do anything
        if($helper->semknoxDisableProductUpstream())  return;

        // edit one product
        if($product = $event->getProduct())
        {
            $productManager->deleteProductById($product->getId());
            $products = $product->getId();
        }

        // edit many products
        elseif($productIds = $event->getProductIds())
        {
            foreach($productIds as $id) {
                $productManager->deleteProductById($id);
            }

            $products = implode(',',$productIds);
        }

        $log = '['.$event->getName().'] remove array('.$products.'): success';
        $helper->log($log, 6, false, $storeId);
    }

}